{ config, lib, pkgs, jovian, ... }:
{
  imports = [ ./desktop ];

  config = lib.mkIf config.jovian.steam.enable {
    jovian = {
      steam = {
        autoStart = true;
        user = config.vars.mainUser;
      };
      decky-loader = {
        enable = true;
        package = pkgs.decky-loader-prerelease;
      };
      devices.steamdeck = {
        enable = true;
        enableGyroDsuService = true;
      };
    };

    # Evil kernel
    boot.kernelPackages = lib.mkForce pkgs.linuxPackages_jovian;

    programs.steam.extest.enable = true;

    hardware.xone.enable = true;

    # Use networkmanager for ui compatibility
    networking = {
      networkmanager.enable = true;
      wireless.enable = lib.mkForce false;
    };

    # Disable conflicting services
    services = {
      keyd.enable = lib.mkForce false;
      tlp.enable = lib.mkForce false;
    };

    # Disable network filesystems
    fileSystems = {
      "midas".enable = false; 
      "kitty".enable = false; 
      "detritus".enable = false; 
      "prophet".enable = false; 
    };

    environment.persistence."/persist".directories = [
      "/etc/NetworkManager/system-connections"
      "/var/lib/decky-loader"
    ];

    nixpkgs.allowUnfreePackages = [
      "steam"
      "steam-jupiter-unwrapped"
      "steamdeck-firmware"
      "steamdeck-hw-theme"
      "xow_dongle-firmware"
    ];

    specialisation.desktop.configuration.config.jovian.steam.enable = lib.mkForce false;
  };
}
